@@ -1,4 +1,4 @@
-/* $Id: RTErrConvertToErrno.cpp 70565 2011-03-15 13:06:05Z michael $ */
+/* $Id: RTErrConvertToErrno.cpp 77339 2012-04-08 16:28:24Z bird $ */
 /** @file
  * IPRT - Convert iprt status codes to errno.
  */
@@ -33,16 +33,7 @@
 
 #include <iprt/assert.h>
 #include <iprt/err.h>
-
-#if defined(RT_OS_DARWIN) && defined(KERNEL)
-# include <sys/errno.h>
-#elif defined(RT_OS_LINUX) && defined(__KERNEL__)
-# include <linux/errno.h>
-#elif defined(RT_OS_FREEBSD) && defined(_KERNEL)
-# include <sys/errno.h>
-#else
-# include <errno.h>
-#endif
+#include <iprt/errno.h>
 
 
 RTDECL(int) RTErrConvertToErrno(int iErr)
