@@ -1,4 +1,4 @@
-/* $Id: alloc-r0drv-linux.c 78705 2012-06-21 15:17:59Z fmehnert $ */
+/* $Id: alloc-r0drv-linux.c 77439 2012-04-12 14:40:45Z bird $ */
 /** @file
  * IPRT - Memory Allocation, Ring-0 Driver, Linux.
  */
@@ -128,7 +128,7 @@ RTR0DECL(int) RTR0MemExecDonate(void *pvMemory, size_t cb)
     int rc;
     AssertReturn(g_HeapExec == NIL_RTHEAPSIMPLE, VERR_WRONG_ORDER);
 
-    rc = RTSpinlockCreate(&g_HeapExecSpinlock);
+    rc = RTSpinlockCreate(&g_HeapExecSpinlock, RTSPINLOCK_FLAGS_INTERRUPT_SAFE, "RTR0MemExecDonate");
     if (RT_SUCCESS(rc))
     {
         rc = RTHeapSimpleInit(&g_HeapExec, pvMemory, cb);
@@ -233,10 +233,9 @@ DECLHIDDEN(int) rtR0MemAllocEx(size_t cb, uint32_t fFlags, PRTMEMHDR *ppHdr)
 # ifdef RTMEMALLOC_EXEC_HEAP
         if (g_HeapExec != NIL_RTHEAPSIMPLE)
         {
-            RTSPINLOCKTMP SpinlockTmp = RTSPINLOCKTMP_INITIALIZER;
-            RTSpinlockAcquireNoInts(g_HeapExecSpinlock, &SpinlockTmp);
+            RTSpinlockAcquire(g_HeapExecSpinlock);
             pHdr = (PRTMEMHDR)RTHeapSimpleAlloc(g_HeapExec, cb + sizeof(*pHdr), 0);
-            RTSpinlockReleaseNoInts(g_HeapExecSpinlock, &SpinlockTmp);
+            RTSpinlockRelease(g_HeapExecSpinlock);
             fFlags |= RTMEMHDR_FLAG_EXEC_HEAP;
         }
         else
@@ -309,10 +308,9 @@ DECLHIDDEN(void) rtR0MemFree(PRTMEMHDR pHdr)
 #ifdef RTMEMALLOC_EXEC_HEAP
     else if (pHdr->fFlags & RTMEMHDR_FLAG_EXEC_HEAP)
     {
-        RTSPINLOCKTMP SpinlockTmp = RTSPINLOCKTMP_INITIALIZER;
-        RTSpinlockAcquireNoInts(g_HeapExecSpinlock, &SpinlockTmp);
+        RTSpinlockAcquire(g_HeapExecSpinlock);
         RTHeapSimpleFree(g_HeapExec, pHdr);
-        RTSpinlockReleaseNoInts(g_HeapExecSpinlock, &SpinlockTmp);
+        RTSpinlockRelease(g_HeapExecSpinlock);
     }
 #endif
 #ifdef RTMEMALLOC_EXEC_VM_AREA
